﻿




FGCOLOR_BLACK = "\x1b[30m"
FGCOLOR_RED = "\x1b[31m"
FGCOLOR_GREEN = "\x1b[32m"
FGCOLOR_YELLOW = "\x1b[33m"
FGCOLOR_BLUE = "\x1b[34m"
FGCOLOR_MAGENTA = "\x1b[35m"
FGCOLOR_CYAN = "\x1b[36m"
FGCOLOR_LIGHT_GRAY = "\x1b[37m"

FGCOLOR_DARK_GRAY = "\x1b[90m"
FGCOLOR_LIGHT_RED = "\x1b[91m"
FGCOLOR_LIGHT_GREEN = "\x1b[92m"
FGCOLOR_LIGHT_YELLOW = "\x1b[93m"
FGCOLOR_LIGHT_BLUE = "\x1b[94m"
FGCOLOR_LIGHT_MAGENTA = "\x1b[95m"
FGCOLOR_LIGHT_CYAN = "\x1b[96m"
FGCOLOR_WHITE = "\x1b[97m"

ALL_FGCOLORS = [
	FGCOLOR_BLACK,
	FGCOLOR_RED,
	FGCOLOR_GREEN,
	FGCOLOR_YELLOW,
	FGCOLOR_BLUE,
	FGCOLOR_MAGENTA,
	FGCOLOR_CYAN,
	FGCOLOR_LIGHT_GRAY,
	FGCOLOR_DARK_GRAY,
	FGCOLOR_LIGHT_RED,
	FGCOLOR_LIGHT_GREEN,
	FGCOLOR_LIGHT_YELLOW,
	FGCOLOR_LIGHT_BLUE,
	FGCOLOR_LIGHT_MAGENTA,
	FGCOLOR_LIGHT_CYAN,
	FGCOLOR_WHITE,
]

BGCOLOR_BLACK = "\x1b[40m"
BGCOLOR_RED = "\x1b[41m"
BGCOLOR_GREEN = "\x1b[42m"
BGCOLOR_YELLOW = "\x1b[43m"
BGCOLOR_BLUE = "\x1b[44m"
BGCOLOR_MAGENTA = "\x1b[45m"
BGCOLOR_CYAN = "\x1b[46m"
BGCOLOR_LIGHT_GRAY = "\x1b[47m"

BGCOLOR_DARK_GRAY = "\x1b[100m"
BGCOLOR_LIGHT_RED = "\x1b[101m"
BGCOLOR_LIGHT_GREEN = "\x1b[102m"
BGCOLOR_LIGHT_YELLOW = "\x1b[103m"
BGCOLOR_LIGHT_BLUE = "\x1b[104m"
BGCOLOR_LIGHT_MAGENTA = "\x1b[105m"
BGCOLOR_LIGHT_CYAN = "\x1b[106m"
BGCOLOR_WHITE = "\x1b[107m"

ALL_BGCOLORS = [
	BGCOLOR_BLACK,
	BGCOLOR_RED,
	BGCOLOR_GREEN,
	BGCOLOR_YELLOW,
	BGCOLOR_BLUE,
	BGCOLOR_MAGENTA,
	BGCOLOR_CYAN,
	BGCOLOR_LIGHT_GRAY,
	BGCOLOR_DARK_GRAY,
	BGCOLOR_LIGHT_RED,
	BGCOLOR_LIGHT_GREEN,
	BGCOLOR_LIGHT_YELLOW,
	BGCOLOR_LIGHT_BLUE,
	BGCOLOR_LIGHT_MAGENTA,
	BGCOLOR_LIGHT_CYAN,
	BGCOLOR_WHITE,
]

STYLE_RESET = "\x1b[0m"



